@@ -2,5 +2,6 @@ from .drop_oldest_duplicate_transformer import (  # noqa: F401
     DropOldestDuplicatesTransformer,
 )
 from .simple_sql_transformer import SimpleSqlServerTransformer  # noqa: F401
-from .timezone_transformer import TimeZoneTransformer  # noqa: F401
+from .timezone_transformer_nc import TimeZoneTransformerNC  # noqa: F401
 from .union_transformer import UnionTransformer  # noqa: F401
+from .union_transformer_nc import UnionTransformerNC  # noqa: F401
