@@ -21,8 +21,14 @@ class SimpleSqlServerTransformer(Transformer):
         # are casted to the target types
         # [f.col("ColumnName).cast("string").alias("ColumnName"), ...]
 
+        # If the format is timestamp, the seconds should be trunc
         target_df = self.server.read_table(self.table_id)
-        col_choose = [f.col(x[0]).cast(x[1]).alias(x[0]) for x in target_df.dtypes]
+        col_choose = [
+            f.date_trunc("second", f.col(x[0])).cast(x[1]).alias(x[0])
+            if x[1] == "timestamp"
+            else f.col(x[0]).cast(x[1]).alias(x[0])
+            for x in target_df.dtypes
+        ]
         df = df.select(col_choose)
 
         return df
