@@ -36,6 +36,13 @@ class DeltaTests(unittest.TestCase):
             },
         )
 
+        tc.register(
+            "MyTbl3",
+            {
+                "path": "/mnt/atc/silver/testdb/testtbl3",
+            },
+        )
+
         # test instantiation without error
         DbHandle.from_tc("MyDb")
         DeltaHandle.from_tc("MyTbl")
@@ -89,7 +96,18 @@ class DeltaTests(unittest.TestCase):
         o.load_into(SimpleLoader(DeltaHandle.from_tc("MyTbl"), mode="overwrite"))
         o.execute()
 
-    def test_07_delete(self):
+    def test_07_write_path_only(self):
+        # check that we can write to the table with no path
+        df = DeltaHandle.from_tc("MyTbl").read()
+
+        dh3 = DeltaHandle.from_tc("MyTbl3")
+
+        dh3.append(df, mergeSchema=True)
+
+        df = dh3.read()
+        df.show()
+
+    def test_08_delete(self):
         dh = DeltaHandle.from_tc("MyTbl")
         dh.drop_and_delete()
 
